@@ -141,7 +141,7 @@ class PARAMETROS:
             if des_aplicacao is None:
                 where_add = ""
             else:
-                where_add = f"""and p.des_aplicacao in ('{"','".join(des_aplicacao)}')"""
+                where_add = f"""and p.des_processo in ('{"','".join(des_aplicacao)}')"""
             stmt =  f"""
                     Select p.hash            									
                           ,p.hash_parent     
@@ -162,7 +162,7 @@ class PARAMETROS:
                        and p.Dat_ini_vigencia <= '{now.strftime("%Y-%m-%d %H:%M:%S")}'
                        and p.flg_status = 'A'
                        {where_add}
-                     order by p.des_aplicacao
+                     order by p.des_processo
                     """
             cur = self._cnn.cursor()
             cur.execute(stmt)
